@@ -3,7 +3,7 @@
 
 #include "config.h"                   
 
-#define REVDATE "21st February 2001" \
+#define REVDATE "21st December 2005" \
 
 #define TRUE 1
 #define FALSE 0
